==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_post.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum_post.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");

define("LAN_01", "Forums");
define("LAN_02", "Replying to: ");
define("LAN_03", "New Thread");
define("LAN_1", "Normal");
define("LAN_2", "Sticky");
define("LAN_3", "Announcement");
define("LAN_4", "Post Poll");
define("LAN_5", "Poll Question:");
define("LAN_6", "Add another option");
define("LAN_7", "Vote option:");
define("LAN_8", "Allow votes from all");
define("LAN_9", "Allow votes from members only");
define("LAN_10", "Login");
define("LAN_11", "Remember me");
define("LAN_16", "Username: ");
define("LAN_17", "Password: ");
define("LAN_20", "Error");
define("LAN_27", "You left required field(s) blank");
define("LAN_28", "You didn't post anything ..");
define("LAN_29", "Edited");
define("LAN_45", "These forums can only be posted to by registered and logged in members, please click");
define("LAN_60", "Start New Thread");
define("LAN_61", "Your Name: ");
define("LAN_62", "Subject: ");
define("LAN_63", "Post: ");
define("LAN_64", "Submit new thread");
define("LAN_73", "Reply: ");
define("LAN_74", "Reply to thread");
define("LAN_77", "Update Thread");
define("LAN_78", "Update Reply");
define("LAN_94", "Posted by");
define("LAN_95", "Unauthorised");
define("LAN_96", "You are not authorised to edit this forum post.");
define("LAN_100", "Thread Topic");
define("LAN_101", "Latest ");
define("LAN_102", " replies");
define("LAN_103", "Review complete thread. (Will open a new window.)");
define("LAN_133", "Thank you");
define("LAN_174", "Signup");
define("LAN_175", "Login");
define("LAN_212", "Forgot password?");
define("LAN_310", "Unable to accept post as that username is registered - if it is your username please login to post.");
define("LAN_311", "Anonymous");
define("LAN_322", "Posted: ");
define("LAN_323", "Preview");
define("LAN_324", "Your message has been successfully posted.");
define("LAN_325", "Click Here to view your message");
define("LAN_326", "Click here to return to the forum");
define("LAN_327", "Review");
define("LAN_380", "If you wish to be notified by email when a reply is posted to your thread please tick the box ");
define("LAN_381", "Forum reply from ");
define("LAN_382", "Post made: ");
define("LAN_383", "Please click the following link to view the full thread ...");
define("LAN_384", "Forum reply at ");
define("LAN_385", "Post: ");
define("LAN_386", "If you do not wish to add a poll to your thread leave the fields blank ");
define("LAN_387", "Go");
define("LAN_388", "Back to top");
define("LAN_389", "Duplicate post, redirecting ...");
define("LAN_390", "Attach file / image");
define("LAN_391", "Options");
define("LAN_392", "File to attach");
define("LAN_393", "<b>Please note</b><br />Allowed file types:");
define("LAN_394", "Any other file types uploaded will be instantly deleted.");
define("LAN_395", "Maximum file size");
define("LAN_396", " bytes");
define("LAN_397", "This thread is locked.");
define("LAN_398", "This forum is read only");
define("LAN_399", "You are not authorized to post to this forum.");
define("LAN_400", "post thread as");
define("LAN_401", "Jump");

define("LAN_402", "poll");
define("LAN_403", "announcement");
define("LAN_404", "sticky");
define("LAN_405", "Forums");
define("LAN_406", "Re:");

//v.616
define("LAN_407", "Redirect");
define("LAN_408", "If your browser does not support meta redirection please click");
define("LAN_409", "HERE");
define("LAN_410", "to be redirected");
define("LAN_411", "here");
define("LAN_412", "to go to the registration page.");

define("LAN_413", "Your poll has been successfully posted.");
define("LAN_414", "Click Here to view your poll");
define("LAN_415", "Your reply has been successfully posted.");

define("LAN_416", "Attach file");
define("LAN_417", "Add another attachment");

define("POLL_506", "Allow multiple choices?");
define("POLL_507", "yes");
define("POLL_508", "no");

define("LAN_FORUM_1", "Uploads disabled: ".e_FILE."public directory is not writable");
define("LAN_FORUM_2", "Duplicate post");


?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_post.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum_post.php $
|     $Revision: 11678 $
|     $Id: lan_forum_post.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Forum");

define("LAN_01", "Forums");
define("LAN_02", "Replying to: ");
define("LAN_03", "New Thread");
define("LAN_1", "Normal");
define("LAN_2", "Sticky");
define("LAN_3", "Announcement");
define("LAN_4", "Post Poll");
define("LAN_5", "Poll Question:");
define("LAN_6", "Add another option");
define("LAN_7", "Vote option:");
define("LAN_8", "Allow votes from all");
define("LAN_9", "Allow votes from members only");
define("LAN_10", "Login");
define("LAN_11", "Remember me");
define("LAN_16", "Username: ");
define("LAN_17", "Password: ");
define("LAN_20", "Error");
define("LAN_27", "You left required field(s) blank");
define("LAN_28", "You didn't post anything ..");
define("LAN_29", "Edited");
define("LAN_45", "These forums can only be posted to by registered and logged in members, please click");
define("LAN_60", "Start New Thread");
define("LAN_61", "Your Name: ");
define("LAN_62", "Subject: ");
define("LAN_63", "Post: ");
define("LAN_64", "Submit new thread");
define("LAN_73", "Reply: ");
define("LAN_74", "Reply to thread");
define("LAN_77", "Update Thread");
define("LAN_78", "Update Reply");
define("LAN_94", "Posted by");
define("LAN_95", "Unauthorised");
define("LAN_96", "You are not authorised to edit this forum post.");
define("LAN_100", "Thread Topic");
define("LAN_101", "Latest ");
define("LAN_102", " replies");
define("LAN_103", "Review complete thread. (Will open a new window.)");
define("LAN_133", "Thank you");
define("LAN_174", "Signup");
define("LAN_175", "Login");
define("LAN_212", "Forgot password?");
define("LAN_310", "Unable to accept post as that username is registered - if it is your username please login to post.");
define("LAN_311", "Anonymous");
define("LAN_322", "Posted: ");
define("LAN_323", "Preview");
define("LAN_324", "Your message has been successfully posted.");
define("LAN_325", "Click Here to view your message");
define("LAN_326", "Click here to return to the forum");
define("LAN_327", "Review");
define("LAN_380", "If you wish to be notified by email when a reply is posted to your thread please tick the box ");
define("LAN_381", "Forum reply from ");
define("LAN_382", "Post made: ");
define("LAN_383", "Please click the following link to view the full thread ...");
define("LAN_384", "Forum reply at ");
define("LAN_385", "Post: ");
define("LAN_386", "If you do not wish to add a poll to your thread leave the fields blank ");
define("LAN_387", "Go");
define("LAN_388", "Back to top");
define("LAN_389", "Duplicate post, redirecting ...");
define("LAN_390", "Attach file / image");
define("LAN_391", "Options");
define("LAN_392", "File to attach");
define("LAN_393", "<b>Please note</b><br />Allowed file types:");
define("LAN_394", "Any other file types uploaded will be instantly deleted.");
define("LAN_395", "Maximum file size");
define("LAN_396", " bytes");
define("LAN_397", "This thread is locked.");
define("LAN_398", "This forum is read only");
define("LAN_399", "You are not authorized to post to this forum.");
define("LAN_400", "post thread as");
define("LAN_401", "Jump");

define("LAN_402", "poll");
define("LAN_403", "announcement");
define("LAN_404", "sticky");
define("LAN_405", "Forums");
define("LAN_406", "Re:");

//v.616
define("LAN_407", "Redirect");
define("LAN_408", "If your browser does not support meta redirection please click");
define("LAN_409", "HERE");
define("LAN_410", "to be redirected");
define("LAN_411", "here");
define("LAN_412", "to go to the registration page.");

define("LAN_413", "Your poll has been successfully posted.");
define("LAN_414", "Click Here to view your poll");
define("LAN_415", "Your reply has been successfully posted.");

define("LAN_416", "Attach file");
define("LAN_417", "Add another attachment");

define("POLL_506", "Allow multiple choices?");
define("POLL_507", "yes");
define("POLL_508", "no");

define("LAN_FORUM_1", "Uploads disabled: ".e_FILE."public directory is not writable");
define("LAN_FORUM_2", "Duplicate post");


?>
